#  Copyright 2021-2026 INFINI Labs
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from .utils import NamespacedClient, query_params


class RemoteClient(NamespacedClient):
    @query_params()
    def info(self, params=None, headers=None):
        """
        `<http://easysearch.cn/guide/en/easysearch/reference/7.x/cluster-remote-info.html>`_
        """
        return self.transport.perform_request(
            "GET", "/_remote/info", params=params, headers=headers
        )
